# jtf.py

Python utilities for interacting with .jtf files.

[View main repository.](https://github.com/NotTimTam/jtf)

[Read the syntax standard.](https://github.com/NotTimTam/jtf/blob/main/SYNTAX.md)

[View an example JTF file.](example.jtf)

Requires Python 3.12 or newer.

# Usage

```python3
from jtf import JTF
```
